==> crystalspace_0.94-20020412-3.tar.gz: crystalspace-0.94.20020412/CS/plugins/aws/awsstdsk.cpp <==
#include "cssysdef.h"
#include "awsstdsk.h"
#include "awscomp.h"
#include "iaws/awsdefs.h"

#include <stdio.h>

void awsStandardSink::Hide (void *sink, iAwsSource *source)
{
  (void)sink;

  iAwsComponent *c = source->GetComponent ();

  c->Hide ();
}

void awsStandardSink::Show (void *sink, iAwsSource *source)
{
  (void)sink;

  iAwsComponent *c = source->GetComponent ();

  c->Show ();
}

void awsStandardSink::HideWindow (void *sink, iAwsSource *source)
{
  sink = (awsStandardSink *)sink;

  iAwsComponent *c = source->GetComponent ();

  if (strcmp (c->Type (), "Window") == 0)
  {
    c->Hide ();
  }
  else
  {
    if (c->Window ()) c->Window ()->Hide ();
  }
}

void awsStandardSink::WindowSlideOutLeft (void *_sink, iAwsSource *source)
{
  awsStandardSink *sink = (awsStandardSink *)_sink;

  iAwsComponent *c = source->GetComponent ();
  iAwsWindow    *win=NULL;

  if (strcmp (c->Type (), "Window") == 0)
  {
    return;
  }
  else
  {
    if (c->Window ()) win=c->Window ();
    else return;

    sink->wmgr->CreateTransition(win, AWS_TRANSITION_SLIDE_OUT_LEFT, 0.05);

  }
}

void awsStandardSink::WindowSlideOutRight (void *_sink, iAwsSource *source)
{
   awsStandardSink *sink = (awsStandardSink *)_sink;

  iAwsComponent *c = source->GetComponent ();
  iAwsWindow    *win=NULL;

  if (strcmp (c->Type (), "Window") == 0)
  {
    return;
  }
  else
  {
    if (c->Window ()) win=c->Window ();
    else return;

    sink->wmgr->CreateTransition(win, AWS_TRANSITION_SLIDE_OUT_RIGHT, 0.05);

  }
}

void awsStandardSink::WindowSlideOutUp (void *_sink, iAwsSource *source)
{
   awsStandardSink *sink = (awsStandardSink *)_sink;

  iAwsComponent *c = source->GetComponent ();
  iAwsWindow    *win=NULL;

  if (strcmp (c->Type (), "Window") == 0)
  {
    return;
  }
  else
  {
    if (c->Window ()) win=c->Window ();
    else return;

    sink->wmgr->CreateTransition(win, AWS_TRANSITION_SLIDE_OUT_UP, 0.05);

  }
}

void awsStandardSink::WindowSlideOutDown (void *_sink, iAwsSource *source)
{
   awsStandardSink *sink = (awsStandardSink *)_sink;

  iAwsComponent *c = source->GetComponent ();
  iAwsWindow    *win=NULL;

  if (strcmp (c->Type (), "Window") == 0)
  {
    return;
  }
  else
  {
    if (c->Window ()) win=c->Window ();
    else return;

    sink->wmgr->CreateTransition(win, AWS_TRANSITION_SLIDE_OUT_DOWN, 0.05);

  }
}


void awsStandardSink::Invalidate (void *sink, iAwsSource *source)
{
  (void)sink;

  iAwsComponent *c = source->GetComponent ();

  c->Invalidate ();
}

awsStandardSink::awsStandardSink (iAws *_wmgr) :
  awsSink(this), wmgr(_wmgr)
{
  RegisterTrigger ("Show", Show);
  RegisterTrigger ("Hide", Hide);
  RegisterTrigger ("HideWindow", HideWindow);
  RegisterTrigger ("Invalidate", Invalidate);
  RegisterTrigger ("SlideOutLeft", WindowSlideOutLeft);
  RegisterTrigger ("SlideOutRight", WindowSlideOutRight);
  RegisterTrigger ("SlideOutUp", WindowSlideOutUp);
  RegisterTrigger ("SlideOutDown", WindowSlideOutDown);
}

awsStandardSink::~awsStandardSink ()
{
}

==> crystalspace_0.98-20040623-2.tar.gz: crystalspace-0.98.20040623/CS/plugins/aws/awsstdsk.cpp <==
#include "cssysdef.h"
#include "awsstdsk.h"
#include "awscomp.h"
#include "iaws/awsdefs.h"

#include <stdio.h>

void awsStandardSink::Hide (void *sink, iAwsSource *source)
{
  (void)sink;

  iAwsComponent *c = source->GetComponent ();

  c->Hide ();
}

void awsStandardSink::Show (void *sink, iAwsSource *source)
{
  (void)sink;

  iAwsComponent *c = source->GetComponent ();

  c->Show ();
}

void awsStandardSink::HideWindow (void *sink, iAwsSource *source)
{
  sink = (awsStandardSink *)sink;
  iAwsComponent *c = source->GetComponent ();
  c->Window()->Hide ();
}

void awsStandardSink::MaximizeWindow (void *sink, iAwsSource *source)
{
  sink = (awsStandardSink *)sink;
  iAwsComponent *c = source->GetComponent ();
  c->Window ()->Maximize ();
}

void awsStandardSink::UnMaximizeWindow (void *sink, iAwsSource *source)
{
  sink = (awsStandardSink *)sink;
  iAwsComponent *c = source->GetComponent ();
  c->Window ()->UnMaximize ();
}

void awsStandardSink::WindowSlideOutLeft (void *_sink, iAwsSource *source)
{
  awsStandardSink *sink = (awsStandardSink *)_sink;

  iAwsComponent *c = source->GetComponent ();
  iAwsComponent *win = c->Window();

  if (c == win)
    return;
  else
    sink->wmgr->CreateTransition(win, AWS_TRANSITION_SLIDE_OUT_LEFT);
}

void awsStandardSink::WindowSlideOutRight (void *_sink, iAwsSource *source)
{
   awsStandardSink *sink = (awsStandardSink *)_sink;

  iAwsComponent *c = source->GetComponent ();
  iAwsComponent *win = c->Window();

  if (c == win)
    return;
  else
    sink->wmgr->CreateTransition(win, AWS_TRANSITION_SLIDE_OUT_RIGHT);
}

void awsStandardSink::WindowSlideOutUp (void *_sink, iAwsSource *source)
{
   awsStandardSink *sink = (awsStandardSink *)_sink;

  iAwsComponent *c = source->GetComponent ();
  iAwsComponent *win = c->Window();

  if (c == win)
    return;
  else
    sink->wmgr->CreateTransition(win, AWS_TRANSITION_SLIDE_OUT_UP);
}

void awsStandardSink::WindowSlideOutDown (void *_sink, iAwsSource *source)
{
   awsStandardSink *sink = (awsStandardSink *)_sink;

  iAwsComponent *c = source->GetComponent ();
  iAwsComponent *win = c->Window();

  if (c == win)
    return;
  else
    sink->wmgr->CreateTransition(win, AWS_TRANSITION_SLIDE_OUT_DOWN);
}


void awsStandardSink::Invalidate (void *sink, iAwsSource *source)
{
  (void)sink;

  iAwsComponent *c = source->GetComponent ();

  c->Invalidate ();
}

awsStandardSink::awsStandardSink (iAws *_wmgr) :
  awsSink(), wmgr(_wmgr)
{
  SetParm (this);
  RegisterTrigger ("Show", Show);
  RegisterTrigger ("Hide", Hide);
  RegisterTrigger ("HideWindow", HideWindow);
  RegisterTrigger ("Invalidate", Invalidate);
  RegisterTrigger ("SlideOutLeft", WindowSlideOutLeft);
  RegisterTrigger ("SlideOutRight", WindowSlideOutRight);
  RegisterTrigger ("SlideOutUp", WindowSlideOutUp);
  RegisterTrigger ("SlideOutDown", WindowSlideOutDown);
  RegisterTrigger ("MaximizeWindow", MaximizeWindow);
  RegisterTrigger ("UnMaximizeWindow", UnMaximizeWindow);
}

awsStandardSink::~awsStandardSink ()
{
}
